@@ -45,16 +45,13 @@ def _get_server_url() -> str:
     if _cached_server_url:
         return _cached_server_url
 
-    override = os.getenv('WATCHLOG_AGENT_URL')
-    if override:
-        _cached_server_url = override.rstrip('/')
-    else:
-        host = (
-            'watchlog-node-agent.monitoring.svc.cluster.local'
-            if _is_running_in_k8s()
-            else '127.0.0.1'
-        )
-        _cached_server_url = f'http://{host}:3774'
+    # No environment variable - only use auto-detection
+    host = (
+        'watchlog-node-agent.monitoring.svc.cluster.local'
+        if _is_running_in_k8s()
+        else '127.0.0.1'
+    )
+    _cached_server_url = f'http://{host}:3774'
 
     return _cached_server_url
 
@@ -62,7 +59,7 @@ class Watchlog:
     def __init__(self, url: str = None):
         """
         url: optional override of the agent URL.
-        If not provided, will auto-detect or use WATCHLOG_AGENT_URL.
+        If not provided, will auto-detect (local or Kubernetes).
         """
         self.base_url = (url or _get_server_url()).rstrip('/')
 
